﻿# Please Configure the following variables....
$SMTPserver = "smtpserver"
$smtpPort = "25"
$expireindays = 7
$from = "Service Desk <servicedesk@yourdomain.com>"
$testing = "False" # Set to ENABLED to send to test recipient below
$testRecipient = ""
$date = Get-Date -format ddMMyyyy

# File path for log
$LogPath = "C:\temp\"

# Generate a random filename
$fileName = [System.IO.Path]::GetRandomFileName() + ".txt"

# Start logging
Start-Transcript "$LogPath$filename"

Import-Module ActiveDirectory
$users = get-aduser -filter * -properties Name, PasswordNeverExpires, PasswordExpired, PasswordLastSet, EmailAddress |where {$_.Enabled -eq "True"} | where { $_.PasswordNeverExpires -eq $false } | where { $_.passwordexpired -eq $false }
$maxPasswordAge = (Get-ADDefaultDomainPasswordPolicy).MaxPasswordAge

# Process Each User for Password Expiry
foreach ($user in $users)
{
    $Name = (Get-ADUser $user | foreach { $_.Name})
    
    $emailaddress = $user.emailaddress
    $passwordSetDate = (get-aduser $user -properties * | foreach { $_.PasswordLastSet })

    $PasswordPol = (Get-AduserResultantPasswordPolicy $user)

    # Check for Fine Grained Password
    if (($PasswordPol) -ne $null)
    {
        $maxPasswordAge = ($PasswordPol).MaxPasswordAge
    }
  
    $expireson = $passwordsetdate + $maxPasswordAge
    $today = (get-date)
    $daystoexpire = (New-TimeSpan -Start $today -End $Expireson).Days
        
    # Check Number of Days to Expiry
    $messageDays = $daystoexpire

    if ($messageDays -eq "1") {
        $messageDays = "in " + $daystoexpire + " day"
    } elseif ($messageDays -eq "0" -or $messageDays -gt 1) {
        $messageDays = "in " + $daystoexpire + " days"
    }

    # Email Subject Set Here
    $subject="Your password will expire $messageDays"
  
    # Email Body Set Here, Note You can use HTML, including Images.
    $body = Get-Content -Path "pwexpire.html" | Out-String

    $body = $body.Replace("{{ExpireText}}", $messageDays)
    $body = $body.Replace("{{Name}}", $Name)

    # If Testing Is Enabled - Email Administrator
    if (($testing) -eq "Enabled")
    {
        $emailaddress = $testRecipient
    }

    # If a user has no email address listed
    if (($emailaddress) -eq $null)
    {
        $emailaddress = $testRecipient    
    }

    # Send Email Message
    if (($daystoexpire -ge "0") -and ($daystoexpire -lt $expireindays))
    {        
        "$messageDays,$date,$Name,$emailaddress,$daystoExpire,$expireson"        
        Send-MailMessage -From $from -To $emailaddress -Subject $subject -Body $body -bodyasHTML -SmtpServer $SMTPserver -port $SMTPPort

    }
    
} # End User Processing

Stop-Transcript